@@ -12,6 +12,8 @@ from .actions import CodePrinter
 from .actions import Debugger
 from .actions import Manhole
 from .actions import VarsPrinter
+from .config import THREADING_SUPPORT_ALIASES
+from .config import load_config
 
 try:
     if os.environ.get("PUREPYTHONHUNTER"):
@@ -31,7 +33,7 @@ except ImportError:
     from .predicates import Query
     from .tracer import Tracer
 
-__version__ = "2.0.1"
+__version__ = "__version__ = '2.1.0'"
 __all__ = (
     'And',
     'CallPrinter',
@@ -49,6 +51,7 @@ __all__ = (
     'trace',
 )
 _last_tracer = None
+_default_config = {}
 
 
 def Q(*predicates, **query):
@@ -73,12 +76,11 @@ def Q(*predicates, **query):
             p() if inspect.isclass(p) and issubclass(p, Action) else p
             for p in predicates
         )
-        if any(isinstance(p, CodePrinter) for p in predicates):
-            if CodePrinter in optional_actions:
-                optional_actions.remove(CodePrinter)
-        if any(isinstance(p, CallPrinter) for p in predicates):
-            if CallPrinter in optional_actions:
-                optional_actions.remove(CallPrinter)
+        if any(isinstance(p, (CallPrinter, CodePrinter)) for p in predicates):
+            # the user provided an action as a filter, remove the action then to prevent double output
+            for action in optional_actions:
+                if action in (CallPrinter, CodePrinter) or isinstance(action, (CallPrinter, CodePrinter)):
+                    optional_actions.remove(action)
         if query:
             predicates += Query(**query),
 
@@ -160,24 +162,30 @@ def trace(*predicates, **options):
         *predicates (callables): Runs actions if **all** of the given predicates match.
     Keyword Args:
         clear_env_var: Disables tracing in subprocess. Default: ``False``.
-        threading_support: Enable tracing *new* threads. Default: ``False``.
+        threading_support: Enable tracing *new* threads. Default: ``None``.
+
+            Modes:
+
+            - ``None`` - automatic (enabled but actions only prefix with thread name if more than 1 thread)
+            - ``False`` - completely disabled
+            - ``True`` - enabled (actions always prefix with thread name)
+
+            You can also use:
+            ``threads_support``, ``thread_support``, ``threadingsupport``, ``threadssupport``, ``threadsupport``,
+            ``threading``, ``threads`` or ``thread``.
         action: Action to run if all the predicates return ``True``. Default: ``CodePrinter``.
         actions: Actions to run (in case you want more than 1).
+        **kwargs: for convenience you can also pass anything that you'd pass to :obj:`hunter.Q`
     """
     global _last_tracer
 
+    predicates, options = load_config(predicates, options)
+
     clear_env_var = options.pop("clear_env_var", False)
-    threading_support = (
-        options.pop("threading_support", False) or
-        options.pop("threads_support", False) or
-        options.pop("thread_support", False) or
-        options.pop("threadingsupport", False) or
-        options.pop("threadssupport", False) or
-        options.pop("threadsupport", False) or
-        options.pop("threading", False) or
-        options.pop("threads", False) or
-        options.pop("thread", False)
-    )
+    threading_support = None
+    for alias in THREADING_SUPPORT_ALIASES:
+        if alias in options:
+            threading_support = options.pop(alias)
     predicate = _prepare_predicate(*predicates, **options)
 
     if clear_env_var:
