@@ -8,8 +8,6 @@ import weakref
 from functools import partial
 from threading import current_thread
 
-from fields import Fields
-
 from .const import SITE_PACKAGES_PATHS
 from .const import SYS_PREFIX_PATHS
 from .util import cached_property
@@ -26,12 +24,11 @@ else:
 
 __all__ = 'Event',
 
-STARTSWITH_TYPES = list, tuple, set
 CYTHON_SUFFIX_RE = re.compile(r'([.].+)?[.](so|pyd)$', re.IGNORECASE)
 LEADING_WHITESPACE_RE = re.compile('(^[ \t]*)(?:[^ \t\n])', re.MULTILINE)
 
 
-class Event(Fields.kind.function.module.filename):
+class Event(object):
     """
     Event wrapper for ``frame, kind, arg`` (the arguments the settrace function gets). This objects is passed to your
     custom functions or predicates.
@@ -48,13 +45,39 @@ class Event(Fields.kind.function.module.filename):
     tracer = None
     threadid = None
     threadname = None
+    depth = None
+    calls = None
 
     def __init__(self, frame, kind, arg, tracer):
+        #: The original Frame object.
         self.frame = frame
+
+        #: The kind of the event, could be one of 'call', 'line', 'return', 'exception',
+        #: 'c_call', 'c_return', or 'c_exception'.
         self.kind = kind
+
+        #: A value that depends on ``kind``
         self.arg = arg
+
+        #: Tracing depth (increases on calls, decreases on returns)
+        self.depth = tracer.depth
+
+        #: A counter for total number of calls up to this Event
+        self.calls = tracer.calls
+
+        #: A reference to the Tracer object
         self.tracer = tracer
 
+    def __eq__(self, other):
+        return (
+            type(self) == type(other) and
+            self.kind == other.kind and
+            self.depth == other.depth and
+            self.function == other.function and
+            self.module == other.module and
+            self.filename == other.filename
+        )
+
     @cached_property
     def threadid(self):
         """
